==> nextcloud-25.0.11.tgz: nextcloud/apps/comments/l10n/da.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentarer",
    "You commented" : "Du kommenterede",
    "{author} commented" : "{author} kommenterede",
    "You commented on %1$s" : "Du kommenterede %1$s",
    "You commented on {file}" : "Du kommenterede {file}",
    "%1$s commented on %2$s" : "%1$s kommenterede %2$s",
    "{author} commented on {file}" : "{author} kommenterede {file}",
    "<strong>Comments</strong> for files" : "<strong>Kommentarer</strong> for filer",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Du blev nævnt på \"{file}\", i en kommentar af en bruger, som siden er blevet slettet",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} nævnte dig i en kommentar til \"{file}\"",
    "Files app plugin to add comments to files" : "Files app plugin til at tilføje kommentarer til filer",
    "Edit comment" : "Rediger kommentar",
    "Delete comment" : "Slet kommentar",
    "Cancel edit" : "Annuller redigering",
    "Post comment" : "Skriv kommentar",
    "No comments yet, start the conversation!" : "Ingen kommentarer endnu, start samtalen!",
    "No more messages" : "Ikke flere beskeder",
    "Retry" : "Prøv igen",
    "Failed to mark comments as read" : "Kunne ikke markere kommentarer som læst",
    "Unable to load the comments list" : "Kan ikke indlæse kommentarlisten",
    "_%n unread comment_::_%n unread comments_" : ["%n ulæst kommentar","%n ulæste kommentarer"],
    "_1 new comment_::_{unread} new comments_" : ["1 ny kommentar","{unread} nye kommentarer"],
    "Comment" : "Kommentér",
    "An error occurred while trying to edit the comment" : "Der opstod en fejl under forsøget på at redigere kommentaren",
    "Comment deleted" : "Kommentar slettet",
    "An error occurred while trying to delete the comment" : "Der opstod en fejl under forsøget på at slette kommentaren",
    "An error occurred while trying to create the comment" : "Der opstod en fejl under forsøget på at oprette kommentaren",
    "%1$s commented" : "%1$s kommenterede"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-26.0.9.tgz: nextcloud/apps/comments/l10n/da.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentarer",
    "You commented" : "Du kommenterede",
    "{author} commented" : "{author} kommenterede",
    "You commented on %1$s" : "Du kommenterede %1$s",
    "You commented on {file}" : "Du kommenterede {file}",
    "%1$s commented on %2$s" : "%1$s kommenterede %2$s",
    "{author} commented on {file}" : "{author} kommenterede {file}",
    "<strong>Comments</strong> for files" : "<strong>Kommentarer</strong> for filer",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Du blev nævnt på \"{file}\", i en kommentar af en bruger, som siden er blevet slettet",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} nævnte dig i en kommentar til \"{file}\"",
    "Files app plugin to add comments to files" : "Files app plugin til at tilføje kommentarer til filer",
    "Edit comment" : "Rediger kommentar",
    "Delete comment" : "Slet kommentar",
    "Cancel edit" : "Annuller redigering",
    "Post comment" : "Skriv kommentar",
    "No comments yet, start the conversation!" : "Ingen kommentarer endnu, start samtalen!",
    "No more messages" : "Ikke flere beskeder",
    "Retry" : "Prøv igen",
    "Failed to mark comments as read" : "Kunne ikke markere kommentarer som læst",
    "Unable to load the comments list" : "Kan ikke indlæse kommentarlisten",
    "_1 new comment_::_{unread} new comments_" : ["1 ny kommentar","{unread} nye kommentarer"],
    "Comment" : "Kommentér",
    "An error occurred while trying to edit the comment" : "Der opstod en fejl under forsøget på at redigere kommentaren",
    "Comment deleted" : "Kommentar slettet",
    "An error occurred while trying to delete the comment" : "Der opstod en fejl under forsøget på at slette kommentaren",
    "An error occurred while trying to create the comment" : "Der opstod en fejl under forsøget på at oprette kommentaren",
    "%1$s commented" : "%1$s kommenterede",
    "_%n unread comment_::_%n unread comments_" : ["%n ulæst kommentar","%n ulæste kommentarer"]
},
"nplurals=2; plural=(n != 1);");
